"""
Configs migration

Generation datetime: 2025-04-29 04:44:51.097887+00:00
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "9b3fea2c"
DOWN_REVISION = "952e9dae"


def upgradeSetting(setting: dict) -> dict:
    """Upgrade setting."""
    setting["match_policy_array_limit"] = 30
    return setting


def downgradeSetting(setting: dict) -> dict:
    """Downgrade setting."""
    setting.pop("match_policy_array_limit", None)
    return setting


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_HANDLERS_LIMITS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "received_images_limit": {"type": "integer", "minimum": 1},
                "raw_event_detections_limit": {"type": "integer", "minimum": 1},
                "raw_event_arrays_limit": {"type": "integer", "minimum": 1},
                "result_candidate_limit": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "received_images_limit": {"type": "integer", "minimum": 1},
                "raw_event_detections_limit": {"type": "integer", "minimum": 1},
                "raw_event_arrays_limit": {"type": "integer", "minimum": 1},
                "result_candidate_limit": {"type": "integer", "minimum": 1},
                "match_policy_array_limit": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        oldDefaultValue={
            "received_images_limit": 8,
            "raw_event_detections_limit": 100,
            "raw_event_arrays_limit": 30,
            "result_candidate_limit": 100,
        },
        newDefaultValue={
            "received_images_limit": 8,
            "raw_event_detections_limit": 100,
            "raw_event_arrays_limit": 30,
            "result_candidate_limit": 100,
            "match_policy_array_limit": 30,
        },
        settingUpgradeFunction=upgradeSetting,
        settingDowngradeFunction=downgradeSetting,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-handlers"],
        newServices=["luna-handlers"],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
